@@ -7,8 +7,8 @@ from langchain_core.tools import BaseTool
 from langchain_core.tools.base import ToolException
 
 from codemie_tools.base.errors import TruncatedOutputError
-from codemie_tools.base.utils import get_encoding, sanitize_string, humanize_error
 from codemie_tools.base.models import ToolOutputFormat
+from codemie_tools.base.utils import get_encoding, sanitize_string, humanize_error
 
 logger = logging.getLogger(__name__)
 
@@ -47,6 +47,8 @@ class CodeMieTool(BaseTool):
 
     def _run(self, *args, **kwargs):
         try:
+            # Validate configuration before executing
+            self._validate_config()
             result = self.execute(*args, **kwargs)
             output, _ = self._limit_output_content(result)
             return self._post_process_output_content(output,*args, **kwargs)
@@ -73,6 +75,54 @@ class CodeMieTool(BaseTool):
     def _healthcheck(self):
         raise NotImplementedError(f"Healthcheck method is not implemented for {self.name}")
 
+    def _validate_config(self) -> None:
+        """
+        Validate configuration fields marked as required at runtime.
+
+        This method checks all fields in self.config that have
+        json_schema_extra={'required_at_runtime': True} and raises
+        ValueError if any are empty.
+
+        Tools can override this method for custom validation logic.
+
+        Raises:
+            ValueError: If required fields are missing or empty
+        """
+        if not hasattr(self, 'config') or not self.config:
+            return  # No config to validate
+
+        missing_fields = self._get_missing_required_fields()
+
+        if missing_fields:
+            raise ValueError(
+                f"Tool config is not set. "
+                f"Please provide {', '.join(missing_fields)} before using the tool."
+            )
+
+    def _get_missing_required_fields(self):
+        """
+        Get list of required fields that are missing or empty.
+
+        Returns:
+            List of missing field names in user-friendly format
+        """
+        missing = []
+
+        # Access model_fields from the class, not the instance (Pydantic v2.11+)
+        for field_name, field_info in self.config.__class__.model_fields.items():
+            # Check if field is marked as required at runtime
+            json_schema_extra = field_info.json_schema_extra or {}
+            if json_schema_extra.get('required_at_runtime'):
+                field_value = getattr(self.config, field_name, None)
+
+                # Check if empty (None, empty string, empty list, etc.)
+                if not field_value:
+                    # Use Pydantic's title if available, otherwise format field name
+                    display_name = field_info.title or field_name.replace('_', ' ')
+                    missing.append(display_name)
+
+        return missing
+
     def calculate_tokens_count(self, output: Any) -> int:
         encoding = get_encoding(self.base_llm_model_name)
 
