@@ -173,30 +173,38 @@ class FileObject(BaseModel):
         """
         return base64.b64encode(self.content).decode(UTF_8)
 
-    def bytes_content(self) -> bytes:
+    def bytes_content(self) -> Optional[bytes]:
         """
         Returns the content of the file as bytes.
-    
+
         If the content is already in bytes format, returns it directly.
         Otherwise, encodes the string content to bytes using UTF-8 encoding.
-    
+        If content is None, returns None.
+
         Returns:
-            bytes: The file content as bytes.
+            Optional[bytes]: The file content as bytes, or None if content is None.
         """
+        if self.content is None:
+            return None
+
         if isinstance(self.content, bytes):
             return self.content
-    
+
         return self.content.encode(UTF_8, errors='replace')
 
-    def string_content(self) -> str:
+    def string_content(self) -> Optional[str]:
         """
         Returns the content of the file as a string.
-    
+
         Uses the to_string_content static method to convert the file content to a string.
-    
+        If content is None, returns None.
+
         Returns:
-            str: The file content as a string.
+            Optional[str]: The file content as a string, or None if content is None.
         """
+        if self.content is None:
+            return None
+
         return self.to_string_content(self.content)
 
     def __str__(self) -> str:
