@@ -2,9 +2,11 @@ from typing import Optional, Dict, Any
 
 from pydantic import model_validator, Field
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CodeMieToolConfig, FileConfigMixin, CredentialTypes
 
-class ConfluenceConfig(CodeMieToolConfig):
+
+class ConfluenceConfig(CodeMieToolConfig, FileConfigMixin):
+    credential_type: CredentialTypes = Field(default=CredentialTypes.CONFLUENCE, exclude=True, frozen=True)
     url: str = Field(
         default="",
         description="URL to your Confluence instance, e.g. http://confluence.example.com/",
