@@ -1,10 +1,12 @@
 from typing import Optional, Dict, Any
 
-from pydantic import model_validator, Field, ConfigDict
+from pydantic import model_validator, Field
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CodeMieToolConfig, CredentialTypes, FileConfigMixin
 
-class JiraConfig(CodeMieToolConfig):
+
+class JiraConfig(CodeMieToolConfig, FileConfigMixin):
+    credential_type: CredentialTypes = Field(default=CredentialTypes.JIRA, exclude=True, frozen=True)
     url: str = Field(
         default="",
         description="URL to your Jira instance, e.g. https://jira.example.com/ or https://jira.example.com/jira/",
