@@ -65,6 +65,9 @@ class GitlabTool(CodeMieTool):
     config: GitlabConfig
     description: str = GITLAB_TOOL.description
 
+    # High value to support large source files.
+    tokens_size_limit: int = 70_000
+
     def _make_request(self, method: str, url: str, headers: dict[str, str],
                       method_arguments: dict) -> requests.Response:
         """
@@ -87,23 +90,17 @@ class GitlabTool(CodeMieTool):
     def execute(self, query: Union[str, dict[str, Any]], *args) -> str:
         """
         Execute GitLab API request with optional custom headers.
-    
+
         Args:
             query: JSON containing request details
             *args: Additional arguments
-    
+
         Returns:
             String response from GitLab API
-    
+
         Raises:
             ToolException: If credentials are missing or request fails
         """
-
-        if not self.config.token or not self.config.url:
-            raise ValueError(
-                "Git config is not set. Please provide it before using the tool."
-            )
-
         try:
             if isinstance(query, str):
                 query = json.loads(query)
