@@ -1,24 +1,4 @@
 from codemie_tools.base.models import ToolMetadata
-
-COMMON_SANDBOX_LIBRARIES = [
-    # Data manipulation and analysis
-    "pandas",
-    "numpy",
-    # Plotting and visualization
-    "matplotlib",
-    "seaborn",
-    "plotly",
-    # Document processing
-    "openpyxl",  # Excel files
-    "xlrd",      # Legacy Excel support
-    "python-docx",  # Word documents
-    "python-pptx",  # PowerPoint
-    "PyPDF2",    # PDF processing
-    "markitdown",  # Convert various file formats to Markdown
-    "pillow",    # Image processing
-    # Utilities
-    "tabulate",  # Pretty tables
-]
 READ_FILE_TOOL = ToolMetadata(
     name="read_file_from_file_system",
     description="""
@@ -161,46 +141,3 @@ GENERATE_IMAGE_TOOL = ToolMetadata(
     Enables the AI assistant to create images based on textual descriptions. This tool utilizes the DALL-E model to generate visual content from text prompts
     """.strip(),
 )
-
-CODE_EXECUTOR_TOOL = ToolMetadata(
-    name="code_executor",
-    description=f"""
-    Execute Python code in a secure, isolated environment.
-
-    CRITICAL CONSTRAINTS:
-    - Python ONLY
-    - ONLY use pre-installed libraries or Python standard library
-    - Pre-installed libraries: {', '.join(COMMON_SANDBOX_LIBRARIES)}
-    - External libraries NOT in this list are NOT available and will cause import errors
-    - Code attempting to import unavailable libraries will FAIL
-
-    Use this tool for:
-    - Running Python code safely
-    - Data analysis and manipulation
-    - Generating visualizations and charts
-    - Processing documents (Excel, PDF, Word, PowerPoint)
-    - Performing calculations and computations
-
-    The code executes in isolation with resource limits and no access to external systems.
-    """.strip(),
-    label="Code Executor",
-    user_description="""
-    Execute Python code to analyze data, generate visualizations, process documents, and perform calculations.
-
-    Key Capabilities:
-    - Data Analysis: Process and analyze datasets using pandas and numpy
-    - Visualizations: Create charts, graphs, and plots with matplotlib, seaborn, and plotly
-    - Document Processing: Work with Excel, Word, PowerPoint, and PDF files
-    - Computations: Perform mathematical calculations and data transformations
-    - Image Processing: Manipulate and process images
-
-    Use Cases:
-    - Generate insights from CSV or Excel data
-    - Create visualizations to illustrate trends and patterns
-    - Extract information from documents
-    - Perform complex calculations and statistical analysis
-    - Transform data between different formats
-
-    The code executes securely with exported files available for download.
-    """.strip(),
-)
