@@ -10,17 +10,29 @@ from langchain_experimental.tools import PythonAstREPLTool
 from codemie_tools.base.base_toolkit import BaseToolkit
 from codemie_tools.base.file_object import MimeType, FileObject
 from codemie_tools.base.models import ToolKit, ToolSet, Tool
-from codemie_tools.file_analysis.csv_tool import CSVTool, get_csv_delimiter
-from codemie_tools.file_analysis.docx_tool import DocxTool
-from codemie_tools.file_analysis.xslx_tool import XlsxTool
+from codemie_tools.file_analysis.csv.tools import CSVTool, get_csv_delimiter
+from codemie_tools.file_analysis.docx.tools import DocxTool
 from codemie_tools.file_analysis.file_analysis_tool import FileAnalysisTool
-from codemie_tools.file_analysis.pdf_tool import PDFTool
-from codemie_tools.file_analysis.pptx_tool import PPTXTool
-from codemie_tools.file_analysis.tool_vars import FILE_ANALYSIS_TOOL, PPTX_TOOL, PDF_TOOL, CSV_TOOL, EXCEL_TOOL, DOCX_TOOL
+from codemie_tools.file_analysis.models import FileAnalysisConfig
+from codemie_tools.file_analysis.pdf.tools import PDFTool
+from codemie_tools.file_analysis.pptx.tools import PPTXTool
+from codemie_tools.file_analysis.tool_vars import FILE_ANALYSIS_TOOL, PPTX_TOOL, PDF_TOOL, CSV_TOOL, EXCEL_TOOL, \
+    DOCX_TOOL
+from codemie_tools.file_analysis.xlsx.tools import XlsxTool
 from codemie_tools.utils.common import normalize_filename
 
 logger = logging.getLogger(__name__)
 
+# Specialized tool classes for file analysis
+# When adding a new specialized tool, add it to this list
+SPECIALIZED_TOOL_CLASSES = [
+    PDFTool,
+    DocxTool,
+    PPTXTool,
+    XlsxTool,
+    CSVTool,
+]
+
 class FileAnalysisToolkit(BaseToolkit):
     model_config = {
         "arbitrary_types_allowed": True
@@ -43,113 +55,73 @@ class FileAnalysisToolkit(BaseToolkit):
             ]
         ).model_dump()
 
-    def _categorize_files(self):
-        """Categorize files based on their mime types.
-    
-        Returns:
-            A dictionary with file types as keys and lists of FileObject as values
-        """
-        file_categories = {
-            'pptx': [],
-            'pdf': [],
-            'csv': [],
-            'excel': [],
-            'docx': [],
-            'other': []
-        }
-    
-        for file_obj in self.files:
-            file_mime = MimeType(file_obj.mime_type)
-            if file_mime.is_pptx:
-                file_categories['pptx'].append(file_obj)
-            elif file_mime.is_pdf:
-                file_categories['pdf'].append(file_obj)
-            elif file_mime.is_csv:
-                file_categories['csv'].append(file_obj)
-            elif file_mime.is_excel:
-                file_categories['excel'].append(file_obj)
-            elif file_mime.is_docx or file_obj.name.lower().endswith('.docx'):
-                file_categories['docx'].append(file_obj)
-            else:
-                file_categories['other'].append(file_obj)
-    
-        return file_categories
-    
     def _process_csv_files_to_tools(self, csv_files):
         """Process CSV files and return appropriate tools.
-    
+
         Args:
             csv_files: List of FileObject instances representing CSV files
-    
+
         Returns:
             List of tools for CSV processing
         """
         if not csv_files:
             return []
-    
+
         tools = []
         dataframes, repl_tool_description = self._pre_process_csv_files(csv_files)
-    
+
         if dataframes:
             logger.debug(f"Initializing PythonAstREPLTool. "
                          f"Locals: {dataframes}. "
                          f"Description: {repl_tool_description}")
             repl_tool = PythonAstREPLTool(locals=dataframes)
             repl_tool.description = repl_tool_description
-            tools.extend([repl_tool, CSVTool(files=csv_files)])
-    
+
+            # Create config for CSV tool
+            csv_config = FileAnalysisConfig(
+                input_files=csv_files,
+                chat_model=self.chat_model
+            )
+            tools.extend([repl_tool, CSVTool(config=csv_config)])
+
         return tools
     
-    def _create_file_type_tool(self, file_type, files):
-        """Create a tool for a specific file type.
-    
-        Args:
-            file_type: The type of files to process
-            files: List of FileObject instances of the specified type
-    
-        Returns:
-            A tool instance for the specified file type, or None if files list is empty
-        """
-        if not files:
-            return None
-    
-        tool_mapping = {
-            'pptx': lambda f: PPTXTool(files=f, chat_model=self.chat_model),
-            'pdf': lambda f: PDFTool(files=f, chat_model=self.chat_model),
-            'excel': lambda f: XlsxTool(files=f, chat_model=self.chat_model),
-            'docx': lambda f: DocxTool(files=f, chat_model=self.chat_model),
-            'other': lambda f: FileAnalysisTool(files=f, chat_model=self.chat_model)
-        }
-    
-        if file_type in tool_mapping:
-            return tool_mapping[file_type](files)
-        return None
-    
     def get_tools(self):
-        """Get tools for processing files based on their types.
-    
+        """Get tools for processing files.
+
+        Each tool will automatically filter files by their supported mime types.
+        Only tools with matching files will be included to optimize LLM context.
+
         Returns:
             List of tools for file processing
         """
         if not self.files:
             return []
-    
-        # Categorize files by type
-        file_categories = self._categorize_files()
-    
-        # Process tools
+
         tools = []
-    
-        # Handle special case for CSV files
-        csv_tools = self._process_csv_files_to_tools(file_categories['csv'])
-        tools.extend(csv_tools)
-    
-        # Handle standard file types
-        for file_type in ['pptx', 'pdf', 'excel', 'docx', 'other']:
-            tool = self._create_file_type_tool(file_type, file_categories[file_type])
-            if tool:
-                tools.append(tool)
-    
+
+        # Create config with all files - each tool will filter what it supports
+        config = FileAnalysisConfig(
+            input_files=self.files,
+            chat_model=self.chat_model
+        )
+
+        # Use the module-level specialized tool classes + FileAnalysisTool
+        tool_classes = SPECIALIZED_TOOL_CLASSES + [FileAnalysisTool]
+
+        # Only add tools that have matching files
+        for tool_class in tool_classes:
+            tool = tool_class(config=config)
+            supported_files = tool._get_supported_files()
+            if supported_files:
+                # CSV tool needs special handling (REPL tool + CSVTool)
+                if tool_class == CSVTool:
+                    csv_tools = self._process_csv_files_to_tools(supported_files)
+                    tools.extend(csv_tools)
+                else:
+                    tools.append(tool)
+                logger.debug(f"Added {tool_class.__name__} (has matching files)")
+
         return tools
 
     @classmethod
