@@ -1,16 +1,15 @@
-from typing import Dict, Any
-from pydantic import BaseModel, model_validator, Field
+from pydantic import BaseModel, Field
 
-from codemie_tools.base.models import CodeMieToolConfig
+from codemie_tools.base.models import CodeMieToolConfig, RequiredField, CredentialTypes
 
 
 class ServiceNowConfig(CodeMieToolConfig):
-    url: str = Field(
+    credential_type: CredentialTypes = Field(default=CredentialTypes.SERVICENOW, exclude=True, frozen=True)
+    url: str = RequiredField(
         description="ServiceNow instance URL",
         json_schema_extra={"placeholder": "https://your-instance.service-now.com"}
     )
-    api_key: str = Field(
-        default="",
+    api_key: str = RequiredField(
         description="ServiceNow API key for authentication",
         json_schema_extra={
             "sensitive": True,
