@@ -2,13 +2,13 @@ import json
 import re
 import traceback
 import urllib.parse
-import requests
 from json import JSONDecodeError
 from typing import Type, Any, Dict
 
-from codemie_tools.base.codemie_tool import CodeMieTool
+import requests
 from langchain_core.tools import ToolException
 
+from codemie_tools.base.codemie_tool import CodeMieTool
 from .models import ServiceNowInput, ServiceNowConfig
 from .tools_vars import SNOW_TABLE_TOOL
 
@@ -65,12 +65,6 @@ class ServiceNowTableTool(CodeMieTool):
         )
 
     def execute(self, method: str, table: str, sys_id: str = "", params: str = "", body: str = "") -> Any:
-
-        if not self.config.api_key or not self.config.url:
-            raise ValueError(
-                "ServiceNow config is not set. Please provide it before using the tool."
-            )
-
         query_params = normalize_query_params(params)
         method = normalize_string(method).upper()
         headers = {
