@@ -1,6 +1,6 @@
 from typing import List
 
-from codemie_tools.base.base_toolkit import BaseToolkit
+from codemie_tools.base.base_toolkit import DiscoverableToolkit
 from codemie_tools.base.models import ToolKit, Tool, ToolSet
 from .servicenow.tools import ServiceNowTableTool
 from .servicenow.tools_vars import SNOW_TABLE_TOOL
@@ -14,7 +14,7 @@ class ITSMToolkitUI(ToolKit):
     label: str = ToolSet.ITSM.value
 
 
-class ITSMToolkit(BaseToolkit):
+class ITSMToolkit(DiscoverableToolkit):
 
     @classmethod
     def get_definition(cls):
