@@ -1,4 +1,5 @@
 from codemie_tools.base.models import ToolMetadata
+from codemie_tools.report_portal.models import ReportPortalConfig
 
 GET_EXTENDED_LAUNCH_DATA_TOOL = ToolMetadata(
     name="get_extended_launch_data",
@@ -20,6 +21,7 @@ GET_EXTENDED_LAUNCH_DATA_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_EXTENDED_LAUNCH_DATA_AS_RAW_TOOL = ToolMetadata(
@@ -41,6 +43,7 @@ GET_EXTENDED_LAUNCH_DATA_AS_RAW_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_LAUNCH_DETAILS_TOOL = ToolMetadata(
@@ -63,6 +66,7 @@ GET_LAUNCH_DETAILS_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_ALL_LAUNCHES_TOOL = ToolMetadata(
@@ -91,6 +95,7 @@ GET_ALL_LAUNCHES_TOOL = ToolMetadata(
     - Custom sorting order (default: startTime,number,DESC)
     - Composite attribute filtering
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 FIND_TEST_ITEM_BY_ID_TOOL = ToolMetadata(
@@ -113,6 +118,7 @@ FIND_TEST_ITEM_BY_ID_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_TEST_ITEMS_FOR_LAUNCH_TOOL = ToolMetadata(
@@ -140,6 +146,7 @@ GET_TEST_ITEMS_FOR_LAUNCH_TOOL = ToolMetadata(
     Optional filtering:
     - Filter by test status (PASSED, FAILED, SKIPPED) or omit to get all items
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_LOGS_FOR_TEST_ITEM_TOOL = ToolMetadata(
@@ -163,6 +170,7 @@ GET_LOGS_FOR_TEST_ITEM_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_USER_INFORMATION_TOOL = ToolMetadata(
@@ -184,6 +192,7 @@ GET_USER_INFORMATION_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 GET_DASHBOARD_DATA_TOOL = ToolMetadata(
@@ -206,6 +215,7 @@ GET_DASHBOARD_DATA_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
 
 UPDATE_TEST_ITEM_TOOL = ToolMetadata(
@@ -230,4 +240,5 @@ UPDATE_TEST_ITEM_TOOL = ToolMetadata(
     2. API key for authentication
     3. Project name
     """.strip(),
+    config_class=ReportPortalConfig,
 )
